.. This README is meant for consumption by humans and pypi. Pypi can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide.html
   This text does not appear on pypi or github. It is a comment.

==============================================================================
collective.tiles.unitegallery
==============================================================================

Implements Unite Gallery as tile for Mosaic in Plone

Features
--------

- Adds a new tile name Unite Gallery that can display a collection of images as tiles or gallery

Todo
----

- When tiles settings will be able to display form fieldsets, add all gallery options

Installation
------------

Install collective.tiles.unitegallery by adding it to your buildout::

    [buildout]

    ...

    eggs =
        collective.tiles.unitegallery


and then running ``bin/buildout``


Contribute
----------

- Issue Tracker: https://github.com/collective/collective.tiles.unitegallery/issues
- Source Code: https://github.com/collective/collective.tiles.unitegallery


Support
-------

If you are having issues, please let us know.


License
-------

The project is licensed under the GPLv2.
